@@ -1,7 +1,9 @@
 # draw regression line from model to extremes of fit (J. Fox)
  
 reg.line<-function(mod, col=palette()[2], lwd=2, lty=1, ...){
-    # last modified 1 Feb 2001 by J. Fox
+    # last modified 2 Aug 2001 by J. Fox
+    if(!is.null(class(mod$na.action)) && 
+        class(mod$na.action) == 'exclude') class(mod$na.action) <- 'omit'
     coef<-coefficients(mod)
     if (length(coef) != 2) error(" Requires simple linear regression.")
     x<-model.matrix(mod)[,2]
